# Created by pyp2rpm-1.1.2
%global pypi_name pyldap

# Do not build python2 package yet, as it would collide with python-ldap
%bcond_with python2

Name:           python-%{pypi_name}
Version:        2.4.35.1
Release:        2%{?dist}
Summary:        An object-oriented Python API to access LDAP directory servers

License:        Python
URL:            https://github.com/%{pypi_name}/%{pypi_name}
Source0:        https://files.pythonhosted.org/packages/source/p/%{pypi_name}/%{pypi_name}-%{version}.tar.gz

# tox.ini from upstream git for better %%check
Source1:        https://raw.githubusercontent.com/%{pypi_name}/%{pypi_name}/%{pypi_name}-%{version}/tox.ini

%if %{with python2}
BuildRequires:  python2-devel
BuildRequires:  python2-setuptools

# for tests
BuildRequires:  python2-pyasn1
BuildRequires:  python2-pyasn1-modules
%endif

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools

BuildRequires:  openldap-devel
BuildRequires:  openssl-devel
BuildRequires:  cyrus-sasl-devel

# for tests
BuildRequires:  /usr/bin/ldapadd
BuildRequires:  /usr/bin/tox
BuildRequires:  /usr/sbin/slaptest

BuildRequires:  python3-pyasn1
BuildRequires:  python3-pyasn1-modules


# Fedora specific patch (from python-ldap package)
Patch0:         %{name}-dirs.patch

# https://github.com/pyldap/pyldap/pull/96
Patch1:         0001-ldif.py-Fix-comparison-of-bytes-and-unicode.patch


%description
pyldap provides an object-oriented API for working with LDAP within
Python programs.  It allows access to LDAP directory servers by wrapping the 
OpenLDAP 2.x libraries, and contains modules for other LDAP-related tasks 
(including processing LDIF, LDAPURLs, LDAPv3 schema, etc.).

%if %{with python2}
%package -n     python2-%{pypi_name}
Summary:        %{summary}
 
Requires:       openldap
Requires:       python2-pyasn1
Requires:       python2-pyasn1-modules
Requires:       python2-setuptools

Provides:       python2-ldap%{?_isa} = %{version}-%{release}
Provides:       python2-ldap = %{version}-%{release}
%{?python_provide:%python_provide python2-%{pypi_name}}
%{?python_provide:%python_provide python2-ldap}
#Obsoletes:      python-ldap < FIXME
#Obsoletes:      python2-ldap < FIXME add specific version when python-ldap goes away

%description -n python2-%{pypi_name}
pyldap provides an object-oriented API for working with LDAP within
Python 2 programs.  It allows access to LDAP directory servers by wrapping the 
OpenLDAP 2.x libraries, and contains modules for other LDAP-related tasks 
(including processing LDIF, LDAPURLs, LDAPv3 schema, etc.).
%endif

%package -n     python3-%{pypi_name}
Summary:        %{summary}
 
Requires:       openldap
Requires:       python3-pyasn1
Requires:       python3-pyasn1-modules
Requires:       python3-setuptools
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-%{pypi_name}
pyldap provides an object-oriented API for working with LDAP within
Python 3 programs.  It allows access to LDAP directory servers by wrapping the 
OpenLDAP 2.x libraries, and contains modules for other LDAP-related tasks 
(including processing LDIF, LDAPURLs, LDAPv3 schema, etc.).


%prep
%setup -qc
mv %{pypi_name}-%{version} python3

pushd python3
%patch0 -p1
%patch1 -p1
cp %{SOURCE1} .
popd

cp -a python{3,2}

find python2 -name '*.py' | xargs sed -i '1s|^#!/usr/bin/env python|#!%{__python2}|'
find python3 -name '*.py' | xargs sed -i '1s|^#!/usr/bin/env python|#!%{__python3}|'


%build
%if %{with python2}
pushd python2
%py2_build
popd
%endif

pushd python3
%py3_build
popd


%install
%if %{with python2}
pushd python2
%py2_install
popd
%endif

pushd python3
%py3_install
popd

%check
%if %{with python2}
pushd python2
LANG=C.UTF-8 TOXENV=py27 tox --sitepackages
popd
%endif

pushd python3
LANG=C.UTF-8 TOXENV=py%{python3_version_nodots} tox --sitepackages
popd

%if %{with python2}
%files -n python2-%{pypi_name}
%doc python2/CHANGES python2/README python2/TODO
%attr(0755,root,root) %{python2_sitearch}/_ldap.so
%{python2_sitearch}/ldapurl.py*
%{python2_sitearch}/ldif.py*
%{python2_sitearch}/dsml.py*
%{python2_sitearch}/ldap
%{python2_sitearch}/%{pypi_name}-%{version}-py2.7.egg-info
%endif


%files -n python3-%{pypi_name}
%doc python3/CHANGES python3/README python3/TODO
%attr(0755,root,root) %{python3_sitearch}/_ldap.cpython-*.so
%{python3_sitearch}/ldapurl.py*
%{python3_sitearch}/ldif.py*
%{python3_sitearch}/dsml.py*
%{python3_sitearch}/__pycache__/*
%{python3_sitearch}/ldap
%{python3_sitearch}/%{pypi_name}-%{version}-py%{python3_version}.egg-info


%changelog
* Tue May 30 2017 Miro Hrončok <mhroncok@redhat.com> - 2.4.35.1-2
- Add a patch from PR #96 (rhbz#1456673)

* Mon May 29 2017 Petr Viktorin <pviktori@redhat.com> - 2.4.35.1-1
- Update to upstream version 2.4.35.1 to fix a regression

* Thu May 18 2017 Petr Viktorin <pviktori@redhat.com> - 2.4.35-1
- Update to upstream version 2.4.35

* Wed Feb 15 2017 Miro Hrončok <mhroncok@redhat.com> - 2.4.28-1
- New version
- Update to the new naming scheme

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.25.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 2.4.25.1-3
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.25.1-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Wed Apr 20 2016 Petr Viktorin <encukou@gmail.com> - 2.4.25.1-1
- Update to new upstream version

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.21-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Nov 19 2015 Petr Viktorin <encukou@gmail.com> - 2.4.21-3
- Include the .so file for Python 3.5

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.21-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Tue Oct 20 2015 Petr Viktorin <pviktori@redhat.com> - 2.4.21-1
- Update to upstream 2.4.21 (Brings in ported ldif module)
- Update tox.ini to match upstream

* Fri Jul 17 2015 Miro Hrončok <mhroncok@redhat.com> - 2.4.20-1
- Initial package.
